using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Data;
using System.Data.SqlClient;

/// <summary>
/// Summary description for DataLayer
/// </summary>
public class DataLayer
{
	private SqlConnection dbConn;

	public DataLayer()
	{
		dbConn = new SqlConnection(System.Configuration.ConfigurationManager.AppSettings["ConnectionString"]);
	}

	private void AddSiteID(ref SqlParameterList paramList)
	{
		if (paramList == null)
			paramList = new SqlParameterList();

		bool found = false;
		foreach (SqlParameter param in paramList)
			if (param.ParameterName.ToLower() == "@siteid")
			{
				found = true;
				break;
			}

		if (!found)
		{
			if (Settings.SiteID > 0)
				paramList.Add(CreateParam("@SiteID", SqlDbType.Int, Settings.SiteID));
			else
				paramList.Add(CreateParam("@SiteID", SqlDbType.Int, DBNull.Value));
		}
	}

	public SqlParameter CreateParam(string paramName, SqlDbType sqlDbType, object paramval)
	{
		SqlParameter param = new SqlParameter(paramName, sqlDbType);
		if(paramval != null)
			param.Value = paramval;
		return param;
	}
	
	public DataSet GetDataSet(string spName)
	{
		return GetDataSet(spName, null);
	}
	
	public DataSet GetDataSet(string spName, SqlParameterList parameters)
	{
		try 
		{
			DataSet ds = new DataSet();

			SqlDataAdapter dataAdapter = new SqlDataAdapter(spName, dbConn);
			dataAdapter.SelectCommand.CommandType = CommandType.StoredProcedure;

			AddSiteID(ref parameters);

			if(parameters != null)
			{
				for(int i=0; i<parameters.Count; i++)
					dataAdapter.SelectCommand.Parameters.Add(parameters[i]);
			}
		
			dbConn.Open();
			dataAdapter.Fill(ds);
			dataAdapter.SelectCommand.Parameters.Clear();
			return ds;
		}
		catch (System.Exception ex) 
		{
			return null;
		}
		finally 
		{
			if(dbConn.State == ConnectionState.Open)
				dbConn.Close();
		}	
	}

	public DataTable GetDataTable(string spName)
	{
		return GetDataTable(spName, null);
	}

	public DataTable GetDataTable(string spName, SqlParameterList parameters)
	{
		DataSet ds = this.GetDataSet(spName, parameters);

		if(ds != null && ds.Tables.Count > 0)
			return ds.Tables[0];
		else
			return null;
	}

	public int ExecuteNonQuery(string spName, SqlParameterList parameters)
	{
		try 
		{
			SqlCommand command = new SqlCommand(spName, dbConn);
			command.CommandType = CommandType.StoredProcedure;
			command.Parameters.Clear();

			AddSiteID(ref parameters);

			if(parameters != null)
			{
				for(int i=0; i<parameters.Count; i++)
					command.Parameters.Add(parameters[i]);
			}

			dbConn.Open();
			return command.ExecuteNonQuery();
		}
		catch (System.Exception ex)
		{
			return -1;
		}
		finally 
		{
			if(dbConn.State == ConnectionState.Open)
				dbConn.Close();
		}
	}

	public object ExecuteScalar(string spName, SqlParameterList parameters)
	{
		try
		{
			
			SqlCommand command = new SqlCommand(spName, dbConn);
			command.CommandType = CommandType.StoredProcedure;
			
			AddSiteID(ref parameters);

			if (parameters != null)
			{
				for (int i = 0; i < parameters.Count; i++)
					command.Parameters.Add(parameters[i]);
			}


			dbConn.Open();
			return command.ExecuteScalar();

		}
		catch (System.Exception ex)
		{
			return false;
		}
		finally
		{
			if (dbConn.State == ConnectionState.Open)
				dbConn.Close();
		}
	}
}

public class SqlParameterList : System.Collections.CollectionBase
{

	public SqlParameter this[ int index ]
	{
		get{ return( (SqlParameter) List[index] ); }
		set{ List[index] = value; }
	}

	public void Add(SqlParameter param)
	{
		List.Add(param);
	}

}