using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.Net.Mail;

public partial class Article : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        
		if (Request["ArticleID"] == null)
			Response.Redirect("~/Default.aspx");
		else
			PostID.Value = Request["ArticleID"];

		if (Request["Confirm"] != null)
		{
			DataLayer dl = new DataLayer();
			SqlParameterList spl = new SqlParameterList();
			spl.Add(dl.CreateParam("@ConfirmGUID", SqlDbType.Char, Request["Confirm"]));
			dl.ExecuteNonQuery("sb_ConfirmComment", spl);
		}

        if (!this.IsPostBack)        
            BindData();

        if (Convert.ToBoolean(Settings.GetSetting("AllowAnonComments", "True")))
            UserComment.Visible = true;
        else if (HttpContext.Current.User.Identity.IsAuthenticated)
            UserComment.Visible = true;
        else
            UserComment.Visible = false;

        if(!this.IsPostBack)
            ViewState["AutoPost"] = DateTime.Now.Day.ToString() + DateTime.Now.Hour.ToString();
    }

	private void BindData()
	{
		DataLayer dl = new DataLayer();
		SqlParameterList spl = new SqlParameterList();
		spl.Add(dl.CreateParam("@PostID", SqlDbType.Int, Convert.ToInt32(Request["ArticleID"])));
		DataSet ds = dl.GetDataSet("sb_GetPost", spl);
		if (ds != null)
		{
			if (ds.Tables[0] != null && ds.Tables[0].Rows.Count > 0)
			{
				DataRow dr = ds.Tables[0].Rows[0];

				if ((dr["Publish"] == DBNull.Value || !Convert.ToBoolean(dr["Publish"])) &&
					!(User.Identity.IsAuthenticated && User.IsInRole("Administrator")))
				{
					//article is not available to the public
					Response.Redirect("~/Default.aspx");
				}

				TitleLabel.Text = dr["Title"].ToString();
				BodyLabel.Text = (dr["Body"].ToString() == "" ? dr["PreviewText"].ToString() : dr["Body"].ToString());
				EntryDate.Text = Convert.ToDateTime(dr["EntryDate"]).ToLongDateString();
				AuthorLabel.Text = dr["AuthorName"].ToString();
				CommentsCountLabel.Text = dr["CommentCount"].ToString();
				if (dr["GalleryID"] == DBNull.Value)
					PostGallery.Visible = false;
				else
					SimpleGallery1.OpenGallery(Convert.ToInt32(dr["GalleryID"]));
				if (dr["ReferenceURL"].ToString() != "")
				{
					RefLink.Visible = true;
					RefLink.Text = "<a target=_blank href=\"" + dr["ReferenceURL"].ToString() + "\">" +
						(dr["ReferenceURLTitle"].ToString() != "" ? dr["ReferenceURLTitle"].ToString() : dr["ReferenceURL"].ToString()) +
						"</a>";
				}
				else
					RefLink.Visible = false;

				if (dr["FileAttachmentID"] != DBNull.Value)
				{
					FileLink.Visible = true;
					FileLink.Text = "<a href=\"GetFile.aspx?FileID=" + dr["FileAttachmentID"].ToString() + "\">Download " + dr["FileName"].ToString() + "...</a>";
				}
				else
					FileLink.Visible = false;
			}
			else
				Response.Redirect("~/Default.aspx");

			if (ds.Tables[1] != null && ds.Tables[1].Rows.Count > 0)
			{
				string keyWordList = "";
				foreach (DataRow dr in ds.Tables[1].Rows)
				{
					keyWordList += (keyWordList != "" ? ", " : "") + dr["Category"].ToString();
				}
				CategoriesList.Text = keyWordList;
				Categories.Visible = true;
			}
			else
				Categories.Visible = false;

            if ((ds.Tables[0] != null && ds.Tables[0].Rows.Count > 0) && (ds.Tables[0].Rows[0]["Comments"] == DBNull.Value || ((bool)ds.Tables[0].Rows[0]["Comments"])))
            {
                if (ds.Tables[2] != null && ds.Tables[2].Rows.Count > 0)
                {
                    CommentsRepeater.DataSource = ds.Tables[2];
                    CommentsRepeater.DataBind();
                }
            }
            else
            {
                Comments.Visible = false;
            }

			if ((ds.Tables[0] != null && ds.Tables[0].Rows.Count > 0) && (ds.Tables[0].Rows[0]["Details"] == DBNull.Value || ((bool)ds.Tables[0].Rows[0]["Details"])))
                PostDetails.Visible = true;
            else
                PostDetails.Visible = false;
		}
	}
	protected void SaveButton_Click(object sender, EventArgs e)
	{
        string autoPost = DateTime.Now.Day.ToString() + DateTime.Now.Hour.ToString();
        string autoPostL = DateTime.Now.Subtract(new TimeSpan(1, 0, 0)).Day.ToString() + DateTime.Now.Subtract(new TimeSpan(1, 0, 0)).Hour.ToString();
        if (autoPost != ViewState["AutoPost"].ToString() && autoPostL != ViewState["AutoPost"].ToString())
            return;
		UserComment.Visible = false;
		SubmitInstructions.Visible = true;
	
		int postId = Convert.ToInt32(PostID.Value);

		DataLayer dl = new DataLayer();
		SqlParameterList spl = new SqlParameterList();
		spl.Add(dl.CreateParam("@PostID", SqlDbType.Int, postId));
		spl.Add(dl.CreateParam("@AuthorName", SqlDbType.VarChar, CommentName.Text));
		spl.Add(dl.CreateParam("@AuthorEmail", SqlDbType.VarChar, CommentEmail.Text));
		spl.Add(dl.CreateParam("@AuthorURL", SqlDbType.VarChar, CommentURL.Text));
		spl.Add(dl.CreateParam("@Comment", SqlDbType.VarChar, Comment.Text));
		string commentGuid = System.Guid.NewGuid().ToString();
		spl.Add(dl.CreateParam("@ConfirmGUID", SqlDbType.Char, commentGuid));
        spl.Add(dl.CreateParam("@ClientIP", SqlDbType.VarChar, Request.UserHostAddress));
		dl.ExecuteScalar("sb_SaveComment", spl);

		string mailServer = System.Configuration.ConfigurationManager.AppSettings["SMTPServer"];
	
		if (mailServer != null && mailServer != "")
		{
			string strTo = CommentEmail.Text;
			string strFrom = System.Configuration.ConfigurationManager.AppSettings["AdminEmailAddress"];
			string strSubject = Settings.GetSetting("SiteTitle") + " Comments Confirmation";
            string user = System.Configuration.ConfigurationManager.AppSettings["SMTPServerUser"];
            string pass = System.Configuration.ConfigurationManager.AppSettings["SMTPServerPassword"];

			SmtpClient mail = new SmtpClient();
            if(user != null && user != "" && pass != null && pass != "")
                mail.Credentials = new System.Net.NetworkCredential( user, pass );
			mail.Host = mailServer;
            
			
			try
			{
				mail.Send(strFrom, strTo, strSubject, CommentName.Text + ",\n\nTo confirm the comments you left at " + Settings.GetSetting("SiteTitle") + " please click on this link (or copy and paste into your web browser):\n\n" +
					this.Request.Url.ToString() + "&Confirm=" + commentGuid + "\n\n" +
					"The text you entered will not appear on the site until you have confirmed the message at the link above.  Thank you.");
			}
			catch(System.Exception ex)
			{
                Response.Write(ex.Message);
                Response.End();
				return;
			}
		}


		//send email
	}

	protected string BuildCommentName(string user, string userurl)
	{
		if (userurl.Length < 1)
			return user;
		else
			return "<a href=\"" + userurl + "\">" + user + "</a>";

	}

	protected void CommentsRepeater_ItemDataBound(object sender, RepeaterItemEventArgs e)
	{
		DataRow dr = ((DataRowView) e.Item.DataItem).Row;
		string userURL =  BuildCommentName(dr["AuthorName"].ToString(), dr["AuthorURL"].ToString());
		((Literal) e.Item.FindControl("CommentUserName")).Text = userURL;

	}
}
